Skip to contents

Fits item factor analysis models for binary responses using full Bayesian inference via Gibbs sampling and auxiliary variables with a probit link function, optionally extending the latent factors with a multivariate Gaussian process to capture spatial dependence. See spifa for the main model-fitting function.

Author

Maintainer: Erick A. Chacón-Montalván erick.chaconmontalvan@wur.nl (ORCID)

Authors:

Other contributors:

  • Emanuele Giorgi [contributor]

  • Benjamin M. Taylor [contributor]